
#include <STC12C5A.H>

//=============================================================
//Define lcd io
sbit CS=P1^0;		//chip select when low
sbit DC=P1^3;		//high :data  low:command   12 
sbit SCL=P1^1;		//SERIAL CLOCK INPUT    
sbit SDI=P1^2;	     //SERIAL DATA INPUT/OUTPUT   00
sbit RES=P2^6;		//reset

//Define key io 
sbit KEY = P2^7;  //NEXT

#define DERECTION 0    //0  vertical screen      2 is a horizontal screen

 
void lcd_Initial(void);
void Write_Cmd_Data(unsigned char);
void Write_Cmd(unsigned char);
void Write_Data(unsigned char DH,unsigned char DL);
void delayms(unsigned int tt);
void Write_Data_U16(unsigned int y);
void LCD_SetPos(unsigned int Xstart,unsigned int Ystart,unsigned int Xend,unsigned int Yend);
void ClearScreen(unsigned int bColor);
void Draw_Circle(unsigned int x0,unsigned int y0,unsigned char r,unsigned int color);
void LCD_DrawRectangle(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2,unsigned int color);
void LCD_DrawLine(unsigned int x1,unsigned int y1,unsigned int x2,unsigned int y2,unsigned int color);
void LCD_DrawPoint(unsigned int x,unsigned int y,unsigned int color);
void showzifustr(unsigned int x,unsigned int y,unsigned char *str,unsigned int dcolor,unsigned int bgcolor);
void showzifu(unsigned int x,unsigned int y,unsigned char value,unsigned int dcolor,unsigned int bgcolor);
  
unsigned int code pic[];
unsigned char code String6_12[];

//===============================================================
//clear screen  
void ClearScreen(unsigned int bColor)
{
 unsigned int i,j;
 LCD_SetPos(0,0,49,160);
 for (i=0;i<161;i++)
	{		
	
	   for (j=0;j<50;j++)
	       Write_Data_U16(bColor);
	}
}



//===============================================================
//write parameter
void  Write_Cmd_Data (unsigned char CMDP)
{ unsigned char i;
 	 
    CS=0;
   	DC=1;
    for(i=0;i<8;i++)
     {  SCL=0;
        if(CMDP&0x80) SDI=1;
       	else SDI=0;
       	SCL=1;
        CMDP=CMDP<<1;
     }
   	CS=1;

}


//=============================================================
//write command

void Write_Cmd(unsigned char CMD)
{ unsigned char i;
 	 
    CS=0;
   	DC=0;
    for(i=0;i<8;i++)
     {  SCL=0;
        if(CMD&0x80) SDI=1;
       	else SDI=0;
       	SCL=1;
        CMD=CMD<<1;
     }
   	CS=1;


}


//==============================================================
//write  data word
void  Write_Data_U16(unsigned int y)
{
	unsigned char m,n;
	m=y>>8;
	n=y;
	Write_Data(m,n);

}


//===================================================================
//write data byte

void Write_Data(unsigned char DH,unsigned char DL)
{unsigned char i;
 	 
    CS=0;
   	DC=1;
    for(i=0;i<8;i++)
     {  SCL=0;
        if(DH&0x80) SDI=1;
       	else SDI=0;
       	SCL=1;
        DH=DH<<1;
     }

    for(i=0;i<8;i++)
     {  SCL=0;
        if(DL&0x80) SDI=1;
       	else SDI=0;
       	SCL=1;
        DL=DL<<1;
     }

   	CS=1;

}



//============================================================
//delay
void delayms(unsigned int count)
{
    int i,j;                                                                                
    for(i=0;i<count;i++)                                                                    
       {
	     for(j=0;j<1000;j++);
       }                                                                                     
}


//show one Character
void showzifu(unsigned int x,unsigned int y,unsigned char value,unsigned int dcolor,unsigned int bgcolor)	
{  
	unsigned char i,j;
	unsigned char *temp=String6_12;    
    LCD_SetPos(x,y,x+7,y+11);       
	temp+=(value-32)*12;
	for(j=0;j<12;j++)
	{
		for(i=0;i<8;i++)
		{ 		     
		 	if((*temp&(1<<(7-i)))!=0)
			{
				Write_Data(dcolor>>8,dcolor);
			} 
			else
			{
				Write_Data(bgcolor>>8,bgcolor);
			}   
		}
		temp++;
	 }
}

//show String
void showzifustr(unsigned int x,unsigned int y,unsigned char *str,unsigned int dcolor,unsigned int bgcolor)	  
{  
	unsigned int x1,y1;
	x1=x;
	y1=y;
	while(*str!='\0')
	{	
		showzifu(x1,y1,*str,dcolor,bgcolor);
		x1+=7;
		str++;
	}	
}




void LCD_DrawPoint(unsigned int x,unsigned int y,unsigned int color)
{
	LCD_SetPos(x,y,x,y);
	Write_Data_U16(color);
} 

void LCD_DrawLine(unsigned int x1,unsigned int y1,unsigned int x2,unsigned int y2,unsigned int color)
{
	unsigned int t; 
	int xerr=0,yerr=0,delta_x,delta_y,distance;
	int incx,incy,uRow,uCol;
	delta_x=x2-x1; 
	delta_y=y2-y1;
	uRow=x1;
	uCol=y1;
	if(delta_x>0)incx=1; 
	else if (delta_x==0)incx=0;
	else {incx=-1;delta_x=-delta_x;}
	if(delta_y>0)incy=1;
	else if (delta_y==0)incy=0;
	else {incy=-1;delta_y=-delta_x;}
	if(delta_x>delta_y)distance=delta_x;  
	else distance=delta_y;
	for(t=0;t<distance+1;t++)
	{
		LCD_DrawPoint(uRow,uCol,color);
		xerr+=delta_x;
		yerr+=delta_y;
		if(xerr>distance)
		{
			xerr-=distance;
			uRow+=incx;
		}
		if(yerr>distance)
		{
			yerr-=distance;
			uCol+=incy;
		}
	}
}



void LCD_DrawRectangle(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2,unsigned int color)
{
	LCD_DrawLine(x1,y1,x2,y1,color);
	LCD_DrawLine(x1,y1,x1,y2,color);
	LCD_DrawLine(x1,y2,x2,y2,color);
	LCD_DrawLine(x2,y1,x2,y2,color);
}


void Draw_Circle(unsigned int x0,unsigned int y0,unsigned char r,unsigned int color)
{
	int a,b;
	a=0;b=r;	  
	while(a<=b)
	{
		LCD_DrawPoint(x0-b,y0-a,color);             //3           
		LCD_DrawPoint(x0+b,y0-a,color);             //0           
		LCD_DrawPoint(x0-a,y0+b,color);             //1                
		LCD_DrawPoint(x0-a,y0-b,color);             //2             
		LCD_DrawPoint(x0+b,y0+a,color);             //4               
		LCD_DrawPoint(x0+a,y0-b,color);             //5
		LCD_DrawPoint(x0+a,y0+b,color);             //6 
		LCD_DrawPoint(x0-b,y0+a,color);             //7
		a++;
		if((a*a+b*b)>(r*r))
		{
			b--;
		}
	}
}



//============================================================
//show gray

void DispRGBGray(void)
{  

	unsigned int  A,B,C;
    unsigned int  i,j,k,DH;

 LCD_SetPos(0,0,49,160);



	for(k=0;k<40;k++)
	{   
    	A=0;
    	B=0;
    	C=0;
		for(i=0;i<16;i++)
		{    
    		for(j=0;j<3;j++)
    		{
     			DH=(A<<11)+(B<<5)+C;
     			Write_Data_U16(DH);
    		}
    		A=A+2;
   			B=B+4;
    		C=C+2;
  		}
		Write_Data_U16(DH);
		Write_Data_U16(DH);
	}


	for(k=0;k<40;k++)
	{   
    	A=0;
    	B=0;
    	C=0;
		for(i=0;i<16;i++)
		{    
    		for(j=0;j<3;j++)
    		{
     			DH=(A<<11)+B+C;
     			Write_Data_U16(DH);
    		}
    		A=A+2;

  		}
		Write_Data_U16(DH);
		Write_Data_U16(DH);

	}

	for(k=0;k<40;k++)
	{   
    	A=0;
    	B=0;
    	C=0;
		for(i=0;i<16;i++)
		{    
    		for(j=0;j<3;j++)
    		{
     			DH=A+(B<<5)+C;
     			Write_Data_U16(DH);
    		}
    		B=B+4;

  		}
		Write_Data_U16(DH);
		Write_Data_U16(DH);
	}

	for(k=0;k<41;k++)
	{   
    	A=0;
    	B=0;
    	C=0;
		for(i=0;i<16;i++)
		{    
    		for(j=0;j<3;j++)
    		{
     			DH=A+B+C;
     			Write_Data_U16(DH);
    		}
    		C=C+2;

  		}
		Write_Data_U16(DH);
		Write_Data_U16(DH);
	}




}




//============================================================
//show picture
void show_picture(void)
{ 
	unsigned char i,j;
	unsigned int n=0;


   LCD_SetPos(0,0,49,160);
	for(j=0;j<161;j++)
	{
		for(i=0;i<50;i++)
		{
            Write_Data_U16(pic[n++]);
	    }
	}


    return;
}


//=============================================================
//LCD Initial

void lcd_Initial(void)
{ 
//  	CS=1;
	delayms(5);
	RES=0;
	delayms(10);
	RES=1;
	delayms(50);  


	 //************* Start Initial Sequence **********// 


  	Write_Cmd(0xFE);
  	Write_Cmd(0xEF);

  	Write_Cmd(0x86);
	Write_Cmd_Data(0xFF);

  	Write_Cmd(0x87);
	Write_Cmd_Data(0xFF);

  	Write_Cmd(0x8E);
	Write_Cmd_Data(0xFF);

  	Write_Cmd(0x8F);
	Write_Cmd_Data(0xFF);

  	Write_Cmd(0x80);
	Write_Cmd_Data(0x13);

  	Write_Cmd(0x81);
	Write_Cmd_Data(0x40);

  	Write_Cmd(0x82);
	Write_Cmd_Data(0x0a);

  	Write_Cmd(0x83);
	Write_Cmd_Data(0x0b);

  	Write_Cmd(0x84);
	Write_Cmd_Data(0x60);

  	Write_Cmd(0x85);
	Write_Cmd_Data(0x80);

  	Write_Cmd(0x89);
	Write_Cmd_Data(0x10);

  	Write_Cmd(0x8A);
	Write_Cmd_Data(0x0F);

  	Write_Cmd(0x8B);
	Write_Cmd_Data(0x02);

  	Write_Cmd(0x8C);
	Write_Cmd_Data(0x59);

  	Write_Cmd(0x8D);
	Write_Cmd_Data(0x55);

  	Write_Cmd(0x3A);
	Write_Cmd_Data(0x05);

  	Write_Cmd(0xEC);
	Write_Cmd_Data(0x00);

  	Write_Cmd(0x7E);
	Write_Cmd_Data(0x30);

  	Write_Cmd(0x74);
	Write_Cmd_Data(0x05);
	Write_Cmd_Data(0x4d);

	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x01);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);

  	Write_Cmd(0xB5);
	Write_Cmd_Data(0x0D);
	Write_Cmd_Data(0x0D);

  	Write_Cmd(0xB6);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);//forwowr:00  backword:60

  	Write_Cmd(0x60);
	Write_Cmd_Data(0x38);
	Write_Cmd_Data(0x09);
	Write_Cmd_Data(0x1E);
	Write_Cmd_Data(0x7A);

  	Write_Cmd(0x63);
	Write_Cmd_Data(0x38);
	Write_Cmd_Data(0xAE);
	Write_Cmd_Data(0x1E);
	Write_Cmd_Data(0x7A);

  	Write_Cmd(0x64);
	Write_Cmd_Data(0x38);
	Write_Cmd_Data(0x0B);
	Write_Cmd_Data(0x70);
	Write_Cmd_Data(0xAB);
	Write_Cmd_Data(0x1E);
	Write_Cmd_Data(0x7A);

  	Write_Cmd(0x66);
	Write_Cmd_Data(0x38);
	Write_Cmd_Data(0x0F);
	Write_Cmd_Data(0x70);
	Write_Cmd_Data(0xAF);
	Write_Cmd_Data(0x1E);
	Write_Cmd_Data(0x7A);

  	Write_Cmd(0x68);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x08);
	Write_Cmd_Data(0x07);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x07);
	Write_Cmd_Data(0x55);
	Write_Cmd_Data(0x6A);

  	Write_Cmd(0x6A);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);

  	Write_Cmd(0x6C);
	Write_Cmd_Data(0x22);
	Write_Cmd_Data(0x02);
	Write_Cmd_Data(0x22);
	Write_Cmd_Data(0x02);
	Write_Cmd_Data(0x22);
	Write_Cmd_Data(0x22);
	Write_Cmd_Data(0x50);

  	Write_Cmd(0x6E);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x02);
	Write_Cmd_Data(0x14);
	Write_Cmd_Data(0x12);
	Write_Cmd_Data(0x0C);
	Write_Cmd_Data(0x0A);
	Write_Cmd_Data(0x1E);
	Write_Cmd_Data(0x1D);
	Write_Cmd_Data(0x08);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x16);
	Write_Cmd_Data(0x15);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x15);
	Write_Cmd_Data(0x16);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x07);
	Write_Cmd_Data(0x1D);
	Write_Cmd_Data(0x1E);
	Write_Cmd_Data(0x09);
	Write_Cmd_Data(0x0B);
	Write_Cmd_Data(0x11);
	Write_Cmd_Data(0x13);
	Write_Cmd_Data(0x01);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);

  	Write_Cmd(0x98);
	Write_Cmd_Data(0x3E);
  	Write_Cmd(0x99);
	Write_Cmd_Data(0x3E);

  	Write_Cmd(0x9b);
	Write_Cmd_Data(0x3b);
  	Write_Cmd(0x93);
	Write_Cmd_Data(0x33);
	Write_Cmd_Data(0x7f);
	Write_Cmd_Data(0x00);

  	Write_Cmd(0x91);
	Write_Cmd_Data(0x0E);
	Write_Cmd_Data(0x09);  

  	Write_Cmd(0x70);
	Write_Cmd_Data(0x04);
	Write_Cmd_Data(0x02);
	Write_Cmd_Data(0x0d);
	Write_Cmd_Data(0x04);
	Write_Cmd_Data(0x02);
	Write_Cmd_Data(0x0d);

  	Write_Cmd(0x71);
	Write_Cmd_Data(0x04);
	Write_Cmd_Data(0x02);
	Write_Cmd_Data(0x0d);

  	Write_Cmd(0xc3);
	Write_Cmd_Data(0x26);
  	Write_Cmd(0xc4);
	Write_Cmd_Data(0x26);
  	Write_Cmd(0xc9);
	Write_Cmd_Data(0x1c);

  	Write_Cmd(0xf0);
	Write_Cmd_Data(0x02);//V62[5:0]
	Write_Cmd_Data(0x03);//V61[5:0]
	Write_Cmd_Data(0x0a);//V59[4:0]
	Write_Cmd_Data(0x06);//V57[4:0]
	Write_Cmd_Data(0x00);//V63[7:4]/V50[3:0]
	Write_Cmd_Data(0x1a);//V43[6:0]

  	Write_Cmd(0xf2);
	Write_Cmd_Data(0x02);//V62[5:0]
	Write_Cmd_Data(0x03);//V61[5:0]
	Write_Cmd_Data(0x0a);//V59[4:0]
	Write_Cmd_Data(0x06);//V57[4:0]
	Write_Cmd_Data(0x00);//V63[7:4]/V50[3:0]
	Write_Cmd_Data(0x1a);//V43[6:0]

  	Write_Cmd(0xf1);
	Write_Cmd_Data(0x38);//V20[6:0] 52
	Write_Cmd_Data(0x78);//V36[7:5]/V6[4:0]
	Write_Cmd_Data(0x1b);//V27[7:5]/V4[4:0]
	Write_Cmd_Data(0x2e);//V2[5:0]
	Write_Cmd_Data(0x2f);//V1[5:0]
	Write_Cmd_Data(0xc8);//V13[7:4]/V0[3:0]

  	Write_Cmd(0xf3);
	Write_Cmd_Data(0x38);//V20[6:0]  
	Write_Cmd_Data(0x74);//V36[7:5]/V6[4:0]
	Write_Cmd_Data(0x12);//V27[7:5]/V4[4:0]
	Write_Cmd_Data(0x2e);//V2[5:0]
	Write_Cmd_Data(0x2f);//V1[5:0]
	Write_Cmd_Data(0xdf);//V13[7:4]/V0[3:0]

  	Write_Cmd(0xBF);
	Write_Cmd_Data(0x00);

  	Write_Cmd(0xF9);
	Write_Cmd_Data(0x40);

  	Write_Cmd(0x36);
	Write_Cmd_Data(0x00);

  if(DERECTION==0)
  {
	Write_Cmd_Data(0x00);
  }
  else
  {
	Write_Cmd_Data(0xC0);
  }
  
  
	Write_Cmd(0x11);
  delayms(200); 

	Write_Cmd(0x29);







}


//===============================================================
 void LCD_SetPos(unsigned int Xstart,unsigned int Ystart,unsigned int Xend,unsigned int Yend)
{
	Write_Cmd(0x2a);   
	Write_Cmd_Data((Xstart>>8)+0x0F);
	Write_Cmd_Data(Xstart+0x0F);
 	Write_Cmd_Data((Xend>>8)+0x0F);
	Write_Cmd_Data(Xend+0x0F);

	Write_Cmd(0x2b);   
	Write_Cmd_Data(Ystart>>8);
	Write_Cmd_Data(Ystart);
	Write_Cmd_Data(Yend>>8);
	Write_Cmd_Data(Yend);
	
  	Write_Cmd(0x2c);//LCD_WriteCMD(GRAMWR);

}

unsigned char code String6_12[]={         
/*--   --*/
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--  !  --*/
0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x20,0x00,0x00,
/*--  "  --*/
0x00,0x28,0x50,0x50,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--  #  --*/
0x00,0x00,0x28,0x28,0xFC,0x28,0x50,0xFC,0x50,0x50,0x00,0x00,
/*--  $  --*/
0x00,0x20,0x78,0xA8,0xA0,0x60,0x30,0x28,0xA8,0xF0,0x20,0x00,
/*-- %  --*/
0x00,0x00,0x48,0xA8,0xB0,0x50,0x28,0x34,0x54,0x48,0x00,0x00,
/*--  &  --*/
0x00,0x00,0x20,0x50,0x50,0x78,0xA8,0xA8,0x90,0x6C,0x00,0x00,
/*--  '  --*/
0x00,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--  (  --*/
0x00,0x04,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x00,
/*--  )  --*/
0x00,0x40,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x40,0x00,
/*--   *  --*/
0x00,0x00,0x00,0x20,0xA8,0x70,0x70,0xA8,0x20,0x00,0x00,0x00,
/*--   +  --*/
0x00,0x00,0x20,0x20,0x20,0xF8,0x20,0x20,0x20,0x00,0x00,0x00,
/*-  ,  --*/
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,
/*--  -  --*/
0x00,0x00,0x00,0x00,0x00,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,
/*--   .  --*/
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x00,
/*--    /  --*/
0x00,0x08,0x10,0x10,0x10,0x20,0x20,0x40,0x40,0x40,0x80,0x00,
/*--   0  --*/
0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0x70,0x00,0x00,
/*--  1  --*/
0x00,0x00,0x20,0x60,0x20,0x20,0x20,0x20,0x20,0x70,0x00,0x00,
/*--   2  --*/
0x00,0x00,0x70,0x88,0x88,0x10,0x20,0x40,0x80,0xF8,0x00,0x00,
/*--   3  --*/
0x00,0x00,0x70,0x88,0x08,0x30,0x08,0x08,0x88,0x70,0x00,0x00,
/*--  4  --*/
0x00,0x00,0x10,0x30,0x50,0x50,0x90,0x78,0x10,0x18,0x00,0x00,
/*--   5  --*/
0x00,0x00,0xF8,0x80,0x80,0xF0,0x08,0x08,0x88,0x70,0x00,0x00,
/*--   6  --*/
0x00,0x00,0x70,0x90,0x80,0xF0,0x88,0x88,0x88,0x70,0x00,0x00,
/*--   7  --*/
0x00,0x00,0xF8,0x90,0x10,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
/*-- 8  --*/
0x00,0x00,0x70,0x88,0x88,0x70,0x88,0x88,0x88,0x70,0x00,0x00,
/*--   9  --*/
0x00,0x00,0x70,0x88,0x88,0x88,0x78,0x08,0x48,0x70,0x00,0x00,
/*--   :  --*/
0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0x20,0x00,0x00,
/*--   ;  --*/
0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x20,0x20,0x00,
/*--   <  --*/
0x00,0x04,0x08,0x10,0x20,0x40,0x20,0x10,0x08,0x04,0x00,0x00,
/*--  =  --*/
0x00,0x00,0x00,0x00,0xF8,0x00,0x00,0xF8,0x00,0x00,0x00,0x00,
/*--  >  --*/
0x00,0x40,0x20,0x10,0x08,0x04,0x08,0x10,0x20,0x40,0x00,0x00,
/*--  ?  --*/
0x00,0x00,0x70,0x88,0x88,0x10,0x20,0x20,0x00,0x20,0x00,0x00,
/*--   @  --*/
0x00,0x00,0x70,0x88,0x98,0xA8,0xA8,0xB8,0x80,0x78,0x00,0x00,
/*--  A  --*/
0x00,0x00,0x20,0x20,0x30,0x50,0x50,0x78,0x48,0xCC,0x00,0x00,
/*--   B  --*/
0x00,0x00,0xF0,0x48,0x48,0x70,0x48,0x48,0x48,0xF0,0x00,0x00,
/*--  C  --*/
0x00,0x00,0x78,0x88,0x80,0x80,0x80,0x80,0x88,0x70,0x00,0x00,
/*--  D  --*/
0x00,0x00,0xF0,0x48,0x48,0x48,0x48,0x48,0x48,0xF0,0x00,0x00,
/*--  E  --*/
0x00,0x00,0xF8,0x48,0x50,0x70,0x50,0x40,0x48,0xF8,0x00,0x00,
/*--   F  --*/
0x00,0x00,0xF8,0x48,0x50,0x70,0x50,0x40,0x40,0xE0,0x00,0x00,
/*--   G  --*/
0x00,0x00,0x38,0x48,0x80,0x80,0x9C,0x88,0x48,0x30,0x00,0x00,
/*--  H  --*/
0x00,0x00,0xCC,0x48,0x48,0x78,0x48,0x48,0x48,0xCC,0x00,0x00,
/*--   I  --*/
0x00,0x00,0xF8,0x20,0x20,0x20,0x20,0x20,0x20,0xF8,0x00,0x00,
/*--   J  --*/
0x00,0x00,0x7C,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0xE0,0x00,
/*--   K  --*/
0x00,0x00,0xEC,0x48,0x50,0x60,0x50,0x50,0x48,0xEC,0x00,0x00,
/*--   L  --*/
0x00,0x00,0xE0,0x40,0x40,0x40,0x40,0x40,0x44,0xFC,0x00,0x00,
/*--  M  --*/
0x00,0x00,0xD8,0xD8,0xD8,0xD8,0xA8,0xA8,0xA8,0xA8,0x00,0x00,
/*--   N  --*/
0x00,0x00,0xDC,0x48,0x68,0x68,0x58,0x58,0x48,0xE8,0x00,0x00,
/*--   O  --*/
0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0x70,0x00,0x00,
/*--   P  --*/
0x00,0x00,0xF0,0x48,0x48,0x70,0x40,0x40,0x40,0xE0,0x00,0x00,
/*--   Q  --*/
0x00,0x00,0x70,0x88,0x88,0x88,0x88,0xE8,0x98,0x70,0x18,0x00,
/*--  R  --*/
0x00,0x00,0xF0,0x48,0x48,0x70,0x50,0x48,0x48,0xEC,0x00,0x00,
/*--   S  --*/
0x00,0x00,0x78,0x88,0x80,0x60,0x10,0x08,0x88,0xF0,0x00,0x00,
/*--   T  --*/
0x00,0x00,0xF8,0xA8,0x20,0x20,0x20,0x20,0x20,0x70,0x00,0x00,
/*--   U  --*/
0x00,0x00,0xCC,0x48,0x48,0x48,0x48,0x48,0x48,0x30,0x00,0x00,
/*--    V  --*/
0x00,0x00,0xCC,0x48,0x48,0x50,0x50,0x30,0x20,0x20,0x00,0x00,
/*--   W  --*/
0x00,0x00,0xA8,0xA8,0xA8,0x70,0x50,0x50,0x50,0x50,0x00,0x00,
/*--    X  --*/
0x00,0x00,0xD8,0x50,0x50,0x20,0x20,0x50,0x50,0xD8,0x00,0x00,
/*--    Y  --*/
0x00,0x00,0xD8,0x50,0x50,0x20,0x20,0x20,0x20,0x70,0x00,0x00,
/*--    Z  --*/
0x00,0x00,0xF8,0x90,0x10,0x20,0x20,0x40,0x48,0xF8,0x00,0x00,
/*--   [  --*/
0x00,0x38,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x38,0x00,
/*--    \  --*/
0x00,0x40,0x40,0x40,0x20,0x20,0x10,0x10,0x10,0x08,0x00,0x00,
/*--    ]  --*/
0x00,0x70,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x70,0x00,
/*--    ^  --*/
0x00,0x20,0x50,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--   _  --*/
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFC,
/*--   `  --*/
0x00,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--  a  --*/
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x38,0x48,0x3C,0x00,0x00,
/*--   b  --*/
0x00,0x00,0xC0,0x40,0x40,0x70,0x48,0x48,0x48,0x70,0x00,0x00,
/*--   c  --*/
0x00,0x00,0x00,0x00,0x00,0x38,0x48,0x40,0x40,0x38,0x00,0x00,
/*--  d  --*/
0x00,0x00,0x18,0x08,0x08,0x38,0x48,0x48,0x48,0x3C,0x00,0x00,
/*--    e  --*/
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x78,0x40,0x38,0x00,0x00,
/*--   f  --*/
0x00,0x00,0x1C,0x20,0x20,0x78,0x20,0x20,0x20,0x78,0x00,0x00,
/*--   g  --*/
0x00,0x00,0x00,0x00,0x00,0x3C,0x48,0x30,0x40,0x78,0x44,0x38,
/*--    h  --*/
0x00,0x00,0xC0,0x40,0x40,0x70,0x48,0x48,0x48,0xEC,0x00,0x00,
/*--   i  --*/
0x00,0x00,0x20,0x00,0x00,0x60,0x20,0x20,0x20,0x70,0x00,0x00,
/*--   j  --*/
0x00,0x00,0x10,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0xE0,
/*--   k  --*/
0x00,0x00,0xC0,0x40,0x40,0x5C,0x50,0x70,0x48,0xEC,0x00,0x00,
/*--  l  --*/
0x00,0x00,0xE0,0x20,0x20,0x20,0x20,0x20,0x20,0xF8,0x00,0x00,
/*--   m  --*/
0x00,0x00,0x00,0x00,0x00,0xF0,0xA8,0xA8,0xA8,0xA8,0x00,0x00,
/*--    n  --*/
0x00,0x00,0x00,0x00,0x00,0xF0,0x48,0x48,0x48,0xEC,0x00,0x00,
/*--    o  --*/
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x48,0x30,0x00,0x00,
/*--   p  --*/
0x00,0x00,0x00,0x00,0x00,0xF0,0x48,0x48,0x48,0x70,0x40,0xE0,
/*--  q  --*/
0x00,0x00,0x00,0x00,0x00,0x38,0x48,0x48,0x48,0x38,0x08,0x1C,
/*--    r  --*/
0x00,0x00,0x00,0x00,0x00,0xD8,0x60,0x40,0x40,0xE0,0x00,0x00,
/*--    s  --*/
0x00,0x00,0x00,0x00,0x00,0x78,0x40,0x30,0x08,0x78,0x00,0x00,
/*--   t  --*/
0x00,0x00,0x00,0x20,0x20,0x70,0x20,0x20,0x20,0x18,0x00,0x00,
/*--    u  --*/
0x00,0x00,0x00,0x00,0x00,0xD8,0x48,0x48,0x48,0x3C,0x00,0x00,
/*--   v  --*/
0x00,0x00,0x00,0x00,0x00,0xEC,0x48,0x50,0x30,0x20,0x00,0x00,
/*--   w  --*/
0x00,0x00,0x00,0x00,0x00,0xA8,0xA8,0x70,0x50,0x50,0x00,0x00,
/*--  x  --*/
0x00,0x00,0x00,0x00,0x00,0xD8,0x50,0x20,0x50,0xD8,0x00,0x00,
/*--   y  --*/
0x00,0x00,0x00,0x00,0x00,0xEC,0x48,0x50,0x30,0x20,0x20,0xC0,
/*--  z  --*/
0x00,0x00,0x00,0x00,0x00,0x78,0x10,0x20,0x20,0x78,0x00,0x00,
/* {  --*/
0x00,0x18,0x10,0x10,0x10,0x20,0x10,0x10,0x10,0x10,0x18,0x00,
/*--    |  --*/
0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
/*--   }  --*/
0x00,0x60,0x20,0x20,0x20,0x10,0x20,0x20,0x20,0x20,0x60,0x00,
/*--  ~  --*/
0x40,0xA4,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,

};  





unsigned int code pic[]=
{//----- D:\̲\Ʒļ\TFT\1.12\ʾͼƬ\501604.bmp
//----- H - L, x direct, 8 pixel mode, 64k color R5G6B5.
//----- width x height = 50 x 160, Total bytes = 16000
0x39e7,0x39e7,0x41e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39c7,0x39e7,
0x39c7,0x39c7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39e7,0x39c7,0x39e7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,
0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,
0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,
0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,
0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,
0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39a7,0x31a6,0x39a7,0x39a7,0x39a7,0x39a7,0x31a6,0x39a7,0x39c7,0x39c7,0x39c7,0x31a6,0x3186,0x39c7,0x39c7,0x3186,0x39a7,0x39c7,0x39c7,0x39c7,0x39a7,0x3186,0x31a6,0x31a6,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x31a6,0x3186,0x3186,0x31a6,0x39c7,0x39c7,0x39c7,0x39a7,0x31a6,0x31a6,0x31a6,0x31a6,0x39a7,0x31a6,0x31a6,0x39c7,0x39c7,
0x31a6,0x39c7,0x4228,0x4228,0x4a29,0x4a29,0x4a29,0x4a29,0x39e7,0x31a6,0x39c7,0x3186,0x39c7,0x4a49,0x526a,0x528a,0x4a49,0x39c7,0x3186,0x39c7,0x31a6,0x39e7,0x526a,0x526a,0x4a49,0x39a7,0x39a7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x3186,0x39e7,0x528a,0x528a,0x4a29,0x31a6,0x39a7,0x39a7,0x39c7,0x4a69,0x4a69,0x4a49,0x4a49,0x4a49,0x4a49,0x39e7,0x3186,0x39c7,0x3186,0x4228,0x5acb,0x528a,0x52aa,0x5aab,0x5aab,0x5aab,0x528a,0x41e8,0x3186,0x4208,0x5acb,0x5aeb,0x5acb,0x5acb,0x62ec,0x5acb,0x41e8,0x31a6,0x3186,0x528a,0x6b4d,0x6b4d,0x52aa,0x3186,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x31a6,0x39e7,0x630c,0x6b4d,0x6b4d,0x5acb,0x31a6,0x39a7,0x3186,0x4a69,0x6b2d,0x62ec,0x5aeb,0x5aeb,0x5acb,0x5acb,0x52aa,0x39e7,0x31a6,
0x39a7,0x4208,0x4228,0x4208,0x4208,0x4208,0x4228,0x4a69,0x52aa,0x4a49,0x3186,0x4228,0x4a49,0x4228,0x4a29,0x4228,0x4228,0x4a69,0x4208,0x31a6,0x39a7,0x4228,0x4a49,0x4a69,0x4208,0x31a6,0x39c7,0x39c7,0x39a7,0x39c7,0x39a7,0x3166,0x4208,0x526a,0x4a29,0x4a49,0x4a29,0x39a7,0x39a7,0x39a7,0x4228,0x4a49,0x4228,0x4228,0x4228,0x4228,0x526a,0x5aab,0x4a69,0x31a6,0x39a7,0x39c7,0x39c7,0x39c7,0x39c7,0x39a7,0x39c7,0x4a69,0x52aa,0x4a49,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39e7,0x39a7,0x39c7,0x39e7,0x39c7,0x39c7,0x31a6,0x39c7,0x39a7,0x39a7,0x39a7,0x31a6,0x31a6,0x4208,0x39e7,0x39c7,0x39c7,0x39c7,0x39c7,0x39a7,0x39a7,0x31a6,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x39c7,0x4a69,0x5aab,0x4a69,0x31a6,
0x39e7,0x526a,0x526a,0x526a,0x526a,0x526a,0x528a,0x528a,0x52aa,0x39e7,0x4208,0x5aab,0x528a,0x528a,0x52aa,0x52aa,0x52aa,0x5acb,0x5aab,0x31a6,0x4a29,0x62ec,0x62ec,0x4a49,0x3166,0x3186,0x3186,0x39a7,0x39c7,0x3186,0x4a29,0x62ec,0x5aeb,0x5aeb,0x5acb,0x62ec,0x5acb,0x39c7,0x3186,0x4208,0x5acb,0x5aab,0x5aab,0x5aab,0x52aa,0x528a,0x528a,0x5aab,0x4208,0x3186,0x4a49,0x526a,0x526a,0x4a69,0x4a69,0x526a,0x526a,0x4a69,0x4208,0x3166,0x4208,0x52aa,0x528a,0x528a,0x528a,0x528a,0x528a,0x5acb,0x526a,0x31a6,0x52aa,0x5acb,0x5acb,0x4a49,0x39a7,0x39e7,0x39e7,0x39c7,0x3166,0x4208,0x62ec,0x62ec,0x5aeb,0x5acb,0x5acb,0x5acb,0x5aeb,0x39e7,0x3166,0x52aa,0x5aeb,0x52aa,0x5aab,0x52aa,0x52aa,0x528a,0x528a,0x4208,0x3186,0x39a7,
0x526a,0x4a69,0x526a,0x39e7,0x39a7,0x39c7,0x39c7,0x39a7,0x3186,0x3186,0x39c7,0x528a,0x52aa,0x526a,0x528a,0x528a,0x52aa,0x5acb,0x39c7,0x39c7,0x5acb,0x52aa,0x52aa,0x5acb,0x5acb,0x5acb,0x62ec,0x39c7,0x39a7,0x5aeb,0x630c,0x5aeb,0x39e7,0x39e7,0x5acb,0x5acb,0x5aeb,0x39c7,0x39c7,0x5acb,0x5aab,0x5aab,0x39e7,0x39c7,0x528a,0x52aa,0x528a,0x39a7,0x3186,0x39a7,0x528a,0x52aa,0x4a29,0x3186,0x3186,0x31a6,0x3186,0x31a6,0x39a7,0x39a7,0x3186,0x41e8,0x52aa,0x5aab,0x5aab,0x5acb,0x5aab,0x4208,0x2965,0x4a69,0x62ec,0x5acb,0x5acb,0x5aeb,0x62ec,0x630c,0x52aa,0x39a7,0x5acb,0x632c,0x62ec,0x41e8,0x2945,0x3186,0x5acb,0x630c,0x630c,0x39e7,0x4228,0x630c,0x630c,0x526a,0x2965,0x3166,0x526a,0x5aeb,0x5acb,0x4a29,0x3186,0x31a6,
0x41e8,0x4208,0x39c7,0x3186,0x39a7,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x3186,0x39c7,0x4a29,0x4a49,0x4228,0x39c7,0x3186,0x3186,0x41e8,0x4228,0x4208,0x4208,0x4208,0x4208,0x4a29,0x39c7,0x31a6,0x4a29,0x4a49,0x41e8,0x3186,0x31a6,0x3186,0x4208,0x4a29,0x4228,0x39c7,0x39e7,0x4a29,0x4a29,0x39c7,0x3186,0x3186,0x39c7,0x4228,0x4208,0x41e8,0x31a6,0x31a6,0x3186,0x3186,0x3186,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x3186,0x3166,0x3186,0x3166,0x3186,0x31a6,0x39a7,0x3186,0x3166,0x3166,0x3186,0x3186,0x3186,0x3166,0x3186,0x31a6,0x3166,0x3166,0x3186,0x31a6,0x31a6,0x39a7,0x3166,0x2965,0x2965,0x3186,0x3186,0x3166,0x3166,0x3186,0x31a6,0x31a6,0x3186,0x3166,0x3166,0x3186,0x31a6,0x31a6,
0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x3186,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x3186,0x3186,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x3186,0x31a6,0x31a6,0x31a6,0x3186,0x3186,0x3186,0x3186,0x31a6,0x31a6,0x3186,0x3186,0x3186,0x31a6,0x31a6,0x3186,0x31a6,0x31a6,0x31a6,0x3186,0x31a6,0x31a6,0x3186,0x3186,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,0x31a6,
0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x31a6,
0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x39c7,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x39a7,
0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x39a7,0x3166,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x39c7,0x2104,
0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x3186,0x31a6,0x3186,0x1082,0x3186,0x3166,0x2165,0x2966,0x2186,0x2965,0x2965,0x2985,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2965,0x2985,0x2965,0x2966,0x19a5,0x3165,0x3166,0x3186,0x3166,0x39a7,0x2925,0x0841,
0x3166,0x4987,0x6147,0x5946,0x5166,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5966,0x5166,0x5946,0x6126,0x5967,0x3966,0x2966,0x3186,0x31a6,0x18c3,0x0841,0x2945,0x4166,0x8968,0x8967,0x8947,0x8947,0x8147,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8947,0x8147,0x8947,0x9928,0x5967,0x2966,0x2966,0x31a6,0x2945,0x0861,0x1062,
0x2986,0x2165,0x4166,0x8167,0x8147,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x8127,0x8947,0x5967,0x2945,0x2986,0x3186,0x39a7,0x20e4,0x0841,0x1082,0x2965,0x2986,0x1985,0x5146,0x8147,0x8147,0x7947,0x7947,0x8127,0x8127,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x8127,0x8127,0x7927,0x7947,0x9147,0x6927,0x2165,0x2186,0x3166,0x3186,0x3166,0x1082,0x0861,0x1062,
0x3166,0x3166,0x2986,0x1965,0x4946,0x8147,0x8927,0x7947,0x7147,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7147,0x8127,0x8947,0x5967,0x3145,0x2945,0x2986,0x3166,0x39a6,0x2104,0x0841,0x1062,0x1062,0x3166,0x2985,0x3165,0x3166,0x1965,0x4126,0x7947,0x9127,0x7947,0x7167,0x8127,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7927,0x7967,0x8167,0x6126,0x2165,0x2185,0x3166,0x3166,0x2986,0x3186,0x18a3,0x0841,0x1062,0x1062,
0x3166,0x2985,0x2985,0x3926,0x2966,0x1985,0x2985,0x6947,0x9128,0x8147,0x7927,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7927,0x7947,0x7947,0x8147,0x8947,0x8127,0x4946,0x1965,0x2965,0x2965,0x2965,0x3145,0x3186,0x2945,0x0841,0x0861,0x1062,0x1062,0x2966,0x3145,0x3165,0x2185,0x3145,0x2965,0x2165,0x2165,0x5146,0x7947,0x8167,0x8127,0x8127,0x7947,0x7947,0x8127,0x8127,0x7927,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x8127,0x7927,0x7947,0x7927,0x7947,0x7947,0x8947,0x8947,0x6926,0x3165,0x2165,0x2966,0x2965,0x3165,0x2965,0x2965,0x39a6,0x18c3,0x0821,0x1062,0x1062,0x1062,
0x2965,0x3165,0x3165,0x2965,0x2965,0x3165,0x3166,0x2185,0x2145,0x3926,0x5946,0x7967,0x8947,0x8927,0x7947,0x7947,0x7947,0x7947,0x7946,0x7927,0x7927,0x7927,0x8127,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x7947,0x8147,0x8147,0x8147,0x6947,0x4146,0x2145,0x2165,0x2966,0x3145,0x2965,0x2965,0x2965,0x3186,0x2965,0x1062,0x0841,0x1062,0x1062,0x1062,0x2945,0x2965,0x2945,0x2945,0x2945,0x2945,0x3145,0x3145,0x2965,0x1985,0x2945,0x3925,0x5146,0x6946,0x8147,0x8947,0x8147,0x8147,0x7946,0x8127,0x8127,0x8127,0x7927,0x7947,0x7946,0x8126,0x8127,0x8146,0x8146,0x8947,0x8127,0x7147,0x6926,0x4145,0x1985,0x1965,0x2966,0x2945,0x2945,0x2965,0x2945,0x2945,0x2945,0x3186,0x2104,0x0821,0x0861,0x0861,0x0861,0x0861,
0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2965,0x3145,0x3125,0x3145,0x2966,0x2145,0x1965,0x2945,0x4145,0x6126,0x6947,0x7947,0x8147,0x8147,0x8166,0x8166,0x8166,0x8147,0x8147,0x8147,0x8147,0x7947,0x7147,0x6927,0x5126,0x3146,0x2165,0x2145,0x2945,0x2946,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2965,0x3166,0x1082,0x0841,0x1062,0x0861,0x0861,0x0861,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2965,0x2945,0x3145,0x2945,0x2945,0x2965,0x2945,0x2145,0x1945,0x2145,0x3945,0x4145,0x4925,0x5146,0x5146,0x5926,0x5926,0x5146,0x4946,0x4145,0x3945,0x3125,0x2145,0x1965,0x1965,0x2965,0x3146,0x3125,0x2965,0x2165,0x2945,0x2945,0x2945,0x2945,0x2945,0x3186,0x2124,0x0841,0x0861,0x0861,0x0861,0x0861,0x0861,
0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2165,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2145,0x2145,0x1945,0x2145,0x2125,0x2125,0x2125,0x2124,0x2144,0x2145,0x2145,0x2945,0x2145,0x2945,0x2925,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x3186,0x18c3,0x0821,0x0861,0x0841,0x0841,0x0841,0x0841,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2965,0x2945,0x0861,0x0841,0x0861,0x0861,0x0861,0x0861,0x0861,
0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x3166,0x20e4,0x0020,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x3165,0x1082,0x0821,0x0841,0x0841,0x0841,0x0861,0x0841,0x0841,
0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2944,0x2164,0x2145,0x2925,0x2925,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2925,0x2965,0x2124,0x0820,0x0841,0x0841,0x0861,0x0841,0x0842,0x0841,0x0861,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2925,0x2925,0x2926,0x2925,0x2145,0x2145,0x2925,0x2925,0x2926,0x2925,0x2945,0x2925,0x3125,0x2965,0x10a3,0x0021,0x0861,0x0840,0x0840,0x0840,0x0841,0x0841,0x1041,
0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2925,0x28e4,0x2883,0x2043,0x2043,0x2042,0x2043,0x1863,0x2043,0x2844,0x1843,0x0000,0x0000,0x0000,0x0800,0x0821,0x0861,0x0860,0x0841,0x0842,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2945,0x2925,0x2945,0x2945,0x2084,0x1822,0x2124,0x2286,0x2b87,0x23e8,0x23e8,0x23e7,0x23e7,0x2be7,0x2be8,0x23a7,0x1b26,0x1325,0x1244,0x10c2,0x1000,0x0000,0x0821,0x0821,0x0841,
0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2945,0x2925,0x2944,0x2944,0x2925,0x2945,0x2905,0x2003,0x2984,0x2cea,0x37ee,0x3ff0,0x3ff0,0x37ef,0x3fef,0x3fef,0x3ff0,0x37f0,0x3ff0,0x2ff0,0x27f1,0x1ff0,0x27f1,0x27f0,0x162a,0x1a23,0x0800,0x0000,0x1041,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2925,0x2144,0x2925,0x2925,0x28c3,0x1822,0x23a8,0x37ef,0x3ff1,0x2e4b,0x23e7,0x22e6,0x2a65,0x2a86,0x22a6,0x2286,0x22a6,0x1a65,0x09e3,0x09e3,0x19e4,0x1305,0x1529,0x1ff0,0x1ff1,0x1d6a,0x0880,0x0800,
0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2924,0x2125,0x2126,0x20c3,0x2022,0x34ea,0x37f2,0x266c,0x29c5,0x1823,0x1802,0x2043,0x2844,0x2864,0x2063,0x2063,0x28a4,0x1001,0x0000,0x0000,0x0800,0x0000,0x0800,0x1041,0x1c29,0x27f2,0x1f2e,0x10a1,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2125,0x2904,0x2123,0x2003,0x24c9,0x37f2,0x2ce9,0x1802,0x3024,0x20c2,0x0800,0x0800,0x0020,0x0020,0x0000,0x1882,0x2925,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0800,0x0000,0x1243,0x27f1,0x1eee,
0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2125,0x2924,0x1822,0x1ac6,0x37f2,0x258a,0x2001,0x20a4,0x18e2,0x49e8,0x8c52,0x8c51,0x9451,0x8431,0x736e,0x52aa,0x1062,0x18e3,0x630c,0x73cf,0x7bd0,0x7baf,0x18c3,0x1000,0x0801,0x0000,0x1244,0x1ff3,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x28e4,0x1865,0x2f6c,0x2fae,0x1884,0x2864,0x2925,0x0040,0x5aeb,0xf77e,0xef5d,0xef3c,0xd69a,0xffff,0xc618,0x0000,0x7bcf,0xffff,0xffbe,0xffdf,0xffdf,0x2986,0x0000,0x0820,0x0801,0x0800,0x1509,
0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2023,0x1ae6,0x37f1,0x2bc6,0x1802,0x2125,0x2124,0x2925,0x2104,0x18c3,0x18e3,0x0000,0x5aab,0xffff,0x4a29,0x0000,0xad55,0xf79e,0x0000,0x0000,0x0841,0x0841,0x0041,0x0021,0x0821,0x0000,0x0881,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2904,0x1803,0x2d49,0x2fef,0x2145,0x2863,0x2124,0x2124,0x2124,0x2104,0x18e3,0x18a3,0x0000,0xf79e,0xbdd7,0x0000,0x0000,0xce59,0xd67a,0x0000,0x0000,0x0000,0x0821,0x0841,0x0821,0x0821,0x0800,0x0800,
0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2124,0x2904,0x2904,0x2124,0x2124,0x2124,0x2124,0x28e4,0x1883,0x36eb,0x2f0c,0x1084,0x28e5,0x2904,0x2124,0x2124,0x2124,0x2124,0x0000,0x736e,0xffff,0x2124,0x0000,0x0000,0xc618,0xdefb,0xb576,0xb576,0x20e4,0x0000,0x0821,0x0821,0x0821,0x0821,0x0000,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x1924,0x1924,0x2104,0x2104,0x2104,0x2104,0x20c4,0x18e3,0x27cd,0x2deb,0x2022,0x2105,0x2104,0x2104,0x2104,0x2104,0x2104,0x0000,0xdedb,0xdefb,0x0000,0x0000,0x0000,0xf7be,0xffff,0xb596,0xffff,0xef3d,0x0841,0x0000,0x0020,0x0020,0x0021,0x0000,
0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2103,0x2104,0x20e4,0x2104,0x2104,0x2103,0x2103,0x20c3,0x18c3,0x2fad,0x260b,0x2022,0x28e5,0x2104,0x2104,0x2104,0x2104,0x1082,0x2124,0xffff,0x9472,0x0000,0x0000,0x0000,0x8c51,0x5aeb,0x0000,0x4208,0xffff,0x5acb,0x0000,0x0821,0x0821,0x0821,0x0000,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x28e4,0x20e4,0x1125,0x1124,0x1104,0x1104,0x10c3,0x0863,0x2f0c,0x2f2c,0x1844,0x28c4,0x2104,0x2104,0x2104,0x2104,0x0000,0x528a,0xffff,0x528a,0x0000,0x0020,0x0020,0x0000,0x0000,0x0000,0x1062,0xffff,0x8c71,0x0000,0x0020,0x0020,0x0020,0x0000,
0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x1904,0x10e4,0x0103,0x00e3,0x18a3,0x20c3,0x30e4,0x38e4,0x38e5,0x2002,0x1569,0x3fef,0x1944,0x1883,0x2104,0x2104,0x2104,0x2104,0x0000,0x8410,0xffff,0x2925,0x0000,0x0000,0x1082,0xad75,0x4208,0x0000,0x1062,0xffff,0x8410,0x0000,0x0020,0x0020,0x0000,0x0800,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x1924,0x2104,0x28e4,0x2104,0x1104,0x00e3,0x10e3,0x38e4,0x6105,0x88e6,0xa906,0xc107,0xd107,0xd8e7,0xe908,0xc806,0x22c6,0x27f0,0x23a6,0x1802,0x2904,0x2104,0x2105,0x2104,0x0000,0xad55,0xffff,0x0841,0x0000,0x0000,0x0841,0xffff,0xe73c,0x0000,0x6b6d,0xffff,0x39c7,0x0000,0x0020,0x0821,0x0000,0x0880,
0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x28e4,0x2104,0x1924,0x0123,0x08c3,0x30e4,0x6925,0xb0e6,0xe0e7,0xf128,0xf909,0xf908,0xf908,0xf107,0xf0e7,0xf8e7,0xf8c8,0x6844,0x072b,0x376f,0x1862,0x2063,0x28e4,0x1905,0x1923,0x0000,0xce59,0xffff,0x0000,0x0000,0x0000,0x0000,0x5aab,0xffff,0xf77d,0xffff,0x9cd3,0x0000,0x0001,0x0020,0x0801,0x0800,0x14e8,0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x28e3,0x2104,0x0904,0x00c3,0x3103,0x9105,0xe107,0xf928,0xf8e8,0xf0e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xf927,0xc006,0x1285,0x1ff1,0x2d4a,0x1001,0x2083,0x2122,0x20e3,0x18c4,0x4a49,0x39c7,0x0000,0x0020,0x0000,0x0020,0x0000,0x2945,0x8410,0x4a8a,0x0000,0x0021,0x0820,0x0800,0x0000,0x1a23,0x1ff3,
0x2104,0x2104,0x2104,0x2104,0x2104,0x2104,0x1904,0x00e3,0x10e3,0x88e5,0xe8e8,0xf909,0xf8c6,0xf0c7,0xe8c8,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xf908,0x9004,0x04c7,0x2ff2,0x2c88,0x1802,0x1802,0x20e5,0x2946,0x0820,0x0000,0x0000,0x0020,0x0000,0x0020,0x0000,0x0000,0x0000,0x0000,0x0000,0x0821,0x0001,0x0000,0x11e2,0x1ff1,0x270e,0x20e4,0x2104,0x20e4,0x20e4,0x2104,0x1104,0x00e3,0x50c4,0xd8e7,0xf908,0xf8c7,0xe8c7,0xe107,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xf0a8,0xf8c7,0xf8c7,0x6803,0x0508,0x27f3,0x2e0c,0x19a4,0x1801,0x2002,0x0800,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0801,0x1428,0x1ff1,0x1f0f,0x08a1,
0x18e3,0x20c4,0x20e4,0x2103,0x08e4,0x08e2,0x88c5,0xf908,0xf908,0xe0e7,0xe107,0xe8e7,0xe8e7,0xe8c7,0xe8e6,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe0e7,0xe0e7,0xe0e7,0xf907,0xf888,0x7002,0x0365,0x0fee,0x37f1,0x35eb,0x1ba7,0x09e3,0x0962,0x0983,0x0983,0x0983,0x0983,0x0183,0x0963,0x0183,0x09c3,0x1284,0x14c9,0x27ee,0x1ff3,0x1d8c,0x1060,0x0000,0x20e3,0x20e4,0x1904,0x08c3,0x18a2,0xa907,0xf909,0xf8c7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8c7,0xe8e7,0xf0c7,0xe8e7,0xe107,0xe8c7,0xf8e7,0xf8e8,0x9804,0x3184,0x14e9,0x0fed,0x17f0,0x1ff0,0x0ff0,0x17ef,0x1fef,0x17f0,0x17f0,0x17f0,0x17f0,0x17f0,0x1ff0,0x27f1,0x1ff0,0x164c,0x1224,0x0800,0x0800,0x0820,
0x20e4,0x1923,0x08e3,0x1885,0xb146,0xf908,0xe8c8,0xd907,0xe8e7,0xf0c6,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe0e7,0xe8e7,0xf0c7,0xe107,0xe8e7,0xe8e7,0xe0e7,0xe107,0xe8c7,0xf8c7,0xf907,0xe847,0xa005,0x5904,0x2a04,0x1326,0x1b86,0x1b65,0x1385,0x1b66,0x1b66,0x1b66,0x1b86,0x13a5,0x0b25,0x0a65,0x08e1,0x0800,0x0000,0x0001,0x0040,0x0800,0x20e4,0x08e3,0x10c2,0xb127,0xf908,0xf0c6,0xe8e7,0xf0e8,0xe866,0xd803,0xe065,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe8e7,0xe908,0xe045,0xd804,0xe086,0xe907,0xf0a7,0xe8c7,0xe107,0xe107,0xe0e7,0xe0e8,0xf0e6,0xf907,0xf867,0xd004,0xb802,0xc002,0xb803,0xb803,0xb803,0xb803,0xb803,0xc003,0xc004,0x3000,0x0000,0x0800,0x0000,0x0000,0x0800,0x0801,0x0001,
0x10e4,0x08a3,0xa8e6,0xf907,0xf0a7,0xe0e7,0xe107,0xf066,0xe1cb,0xdc52,0xe169,0xe044,0xe8e7,0xe8c7,0xe0e7,0xe0e7,0xe8c7,0xe8c7,0xe865,0xe26d,0xd452,0xe8a7,0xe865,0xe107,0xe8c7,0xf0a7,0xe8e7,0xe8c7,0xe8e7,0xe0e7,0xe8e7,0xe085,0xf805,0xf806,0xf825,0xf805,0xf806,0xf806,0xf806,0xf806,0xf806,0xf806,0xd866,0x1821,0x0000,0x0801,0x0020,0x0820,0x0800,0x0020,0x00a3,0x80c4,0xf928,0xf0a7,0xe0e7,0xe8c7,0xe0e7,0xd802,0xed77,0xffff,0xee3a,0xd803,0xe8a5,0xe0e7,0xe0e6,0xe8c6,0xe0e7,0xe887,0xd805,0xf6dc,0xffff,0xe4f5,0xd802,0xe8c7,0xe8e7,0xe8c7,0xe8c7,0xe0e7,0xe8e7,0xe8e7,0xe8e7,0xe826,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xf005,0xe004,0xf827,0xc065,0x0040,0x0000,0x0800,0x0020,0x0020,0x0000,
0x40c3,0xf908,0xf8c7,0xe0c7,0xe0e7,0xf0a7,0xe8c7,0xd003,0xe391,0xffff,0xffff,0xe30f,0xe001,0xe107,0xe8c7,0xe8c6,0xe0e7,0xe0c7,0xe803,0xecb4,0xffff,0xf7ff,0xd9ca,0xe803,0xe107,0xe8c6,0xe0e6,0xe0e6,0xf086,0xe107,0xe0a6,0xf005,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xd825,0xf005,0xf827,0x7883,0x0020,0x0001,0x0800,0x0020,0x0000,0xd0e6,0xf8e8,0xe8a7,0xe8c7,0xe0e7,0xe8c7,0xe0e6,0xe886,0xd804,0xee5a,0xffff,0xef5d,0xd865,0xe844,0xe0e8,0xe8c8,0xe805,0xd804,0xd801,0xd003,0xf73c,0xffff,0xee58,0xd803,0xe886,0xe8e7,0xe8c7,0xe804,0xd024,0xd804,0xe803,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe005,0xe805,0xf005,0xf005,0xf866,0x4042,0x0020,0x0001,0x0020,0x0800,
0xf8e8,0xe8c7,0xe0c7,0xe8a7,0xe0e7,0xe8c7,0xe0e7,0xe0e7,0xe802,0xd20b,0xffff,0xffff,0xe433,0xd802,0xe8c7,0xd804,0xe22d,0xed98,0xe618,0xd1aa,0xd26c,0xffff,0xffff,0xd32e,0xe802,0xf0a7,0xe005,0xe2ef,0xde19,0xe577,0xd9cb,0xd802,0xe825,0xe805,0xe805,0xe805,0xe806,0xe805,0xe001,0xe001,0xe805,0xe806,0xe026,0xe024,0xf806,0xc045,0x0040,0x0000,0x0800,0x0800,0xf8c7,0xe8c6,0xe0e7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c6,0xd002,0xe535,0xffff,0xffff,0xd948,0xe801,0xe20c,0xf7ff,0xffff,0xffff,0xffff,0xc22b,0xe557,0xffff,0xef3d,0xe044,0xe002,0xd32f,0xffff,0xffff,0xffff,0xf7ff,0xd9ca,0xe802,0xe805,0xf026,0xf005,0xd800,0xd803,0xeb50,0xe330,0xe004,0xe805,0xe805,0xe805,0xf005,0xf827,0x5042,0x0000,0x0000,0x0000,
0xe8c7,0xe0e7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8e7,0xe024,0xd127,0xff9f,0xffff,0xed56,0xc800,0xf5b7,0xffff,0xffff,0xffff,0xffff,0xf598,0xc968,0xffff,0xffff,0xdc11,0xd000,0xfedc,0xffff,0xffff,0xffff,0xffff,0xf577,0xe003,0xe005,0xe002,0xd801,0xd9ea,0xee18,0xffff,0xffff,0xd96a,0xe802,0xe805,0xe805,0xe805,0xf806,0xb865,0x0020,0x0000,0x0800,0xe0c7,0xe0c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xd802,0xe3f1,0xffff,0xffff,0xd109,0xecb4,0xffff,0xf7ff,0xf7ff,0xffff,0xfedc,0xd800,0xe3d1,0xffff,0xf79e,0xc8a6,0xfe19,0xffff,0xffff,0xf7ff,0xffff,0xf597,0xd800,0xe000,0xd8e6,0xe4f5,0xffff,0xffff,0xffff,0xdd56,0xd884,0xe804,0xe805,0xe805,0xe805,0xf005,0xf846,0x4042,0x0000,0x0020,
0xe8a7,0xe0e6,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe845,0xd065,0xf6fc,0xffff,0xed97,0xc989,0xffff,0xffff,0xffff,0xffff,0xd24c,0xc800,0xdbd2,0xf7ff,0xffff,0xdc53,0xd22b,0xffff,0xffff,0xffff,0xffff,0xd0a6,0xc800,0xdbf0,0xf7bf,0xffff,0xffff,0xee9b,0xda8b,0xd802,0xf003,0xe805,0xe805,0xe805,0xe805,0xe806,0xf825,0x9844,0x0020,0x0000,0xe8c7,0xe0e6,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe0c7,0xe8c7,0xe002,0xdacd,0xffff,0xffff,0xcaad,0xc8c8,0xed15,0xed57,0xd24d,0xc969,0xee19,0xffff,0xffff,0xffff,0xffff,0xc1c9,0xd169,0xe556,0xe4f4,0xc96a,0xca0a,0xf69b,0xffff,0xffff,0xf7be,0xe3b0,0xd803,0xe800,0xf005,0xe826,0xe805,0xe805,0xe805,0xe805,0xe006,0xf804,0xd846,0x0821,0x0000,
0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8a5,0xd003,0xe597,0xffff,0xf7df,0xdbb1,0xc9ca,0xb949,0xe412,0xffff,0xffff,0xffff,0xe535,0xee39,0xffff,0xef5d,0xdace,0xc169,0xb907,0xe494,0xffff,0xffff,0xf7ff,0xdcd4,0xd0e6,0xe000,0xe803,0xe806,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe806,0xf005,0xf847,0x4863,0x0000,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c6,0xe8e8,0xe001,0xe28b,0xffff,0xffff,0xffff,0xffff,0xffbf,0xffff,0xffff,0xf69b,0xe2ad,0xc800,0xdb6f,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe619,0xd9ea,0xd800,0xf001,0xe825,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe005,0xf827,0x8844,0x0000,
0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xf0a7,0xd802,0xe4b3,0xffff,0xffff,0xffff,0xffff,0xffff,0xff9e,0xdbf1,0xe045,0xe801,0xd804,0xe5f9,0xffff,0xffff,0xf7ff,0xffff,0xffff,0xef3d,0xd30e,0xd802,0xe800,0xe804,0xe806,0xe806,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe025,0xe026,0xf826,0xb044,0x0020,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xf024,0xd8c8,0xf75e,0xffff,0xffff,0xffff,0xffff,0xffff,0xe473,0xd000,0xe845,0xe824,0xd9ca,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdace,0xd800,0xf003,0xe046,0xe806,0xe005,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe825,0xf006,0xf805,0xc865,0x1021,
0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe002,0xdace,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdb2f,0xe002,0xf0c6,0xd802,0xe3f1,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe169,0xe802,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe025,0xf006,0xe026,0x2021,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c6,0xd803,0xed36,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe1eb,0xe804,0xf066,0xd025,0xf67a,0xffff,0xffff,0xffff,0xffff,0xffff,0xef7d,0xe046,0xe803,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe025,0xf805,0xf026,0x3022,
0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe845,0xd8c8,0xff7e,0xffff,0xffff,0xffff,0xffff,0xffff,0xef3c,0xd8c7,0xe846,0xe003,0xe9ab,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xedf9,0xe003,0xe804,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe005,0xe805,0xf805,0xf026,0x4022,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe002,0xdb0f,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xedf8,0xd804,0xf087,0xd801,0xe411,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf454,0xd801,0xe805,0xe806,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe005,0xe805,0xf005,0xf046,0x4022,
0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe0c7,0xe0c7,0xe8a7,0xe8a7,0xe886,0xd802,0xe596,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe4b4,0xe003,0xe865,0xd824,0xee9a,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe32f,0xd801,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe825,0xe805,0xf026,0x3822,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8c7,0xe8a7,0xe8a7,0xe0c7,0xe025,0xd907,0xff9e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdb4f,0xd803,0xe003,0xda0b,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd1ca,0xe002,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe825,0xf005,0xf026,0x3822,
0xe8c6,0xe8c6,0xe8c6,0xe8c6,0xe8c6,0xe8c6,0xe8a7,0xe0e6,0xe8c6,0xe803,0xe30f,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7ff,0xe98a,0xe804,0xe002,0xec53,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf71c,0xe026,0xe803,0xe805,0xe005,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe005,0xe805,0xf805,0xe046,0x2821,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe0c6,0xe0c6,0xf886,0xd803,0xed15,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7ff,0xe1aa,0xe803,0xd804,0xf639,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef5d,0xd846,0xf003,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xf806,0xc866,0x1021,
0xe0c6,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe8a7,0xe8a7,0xe8a6,0xf045,0xc886,0xeedc,0xffff,0xffff,0xee3a,0xec93,0xff9e,0xffff,0xffff,0xe391,0xd800,0xd969,0xf7df,0xffff,0xffff,0xf577,0xecb4,0xffff,0xffff,0xffff,0xe20c,0xe801,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe825,0xf826,0xb044,0x0020,0xe8a6,0xe8c6,0xe8a7,0xe8a7,0xe8a7,0xe8a7,0xe8c7,0xe0c6,0xe003,0xd9eb,0xffff,0xffff,0xffff,0xd1aa,0xc800,0xed56,0xffff,0xffff,0xed78,0xd000,0xe30e,0xffff,0xffff,0xffbe,0xc803,0xc800,0xf67a,0xffff,0xffff,0xe413,0xd800,0xf005,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe025,0xe826,0xf846,0x8843,0x0000,
0xe8a7,0xe8a7,0xe8a7,0xe8a7,0xe8a7,0xe8a7,0xe0c6,0xe0e6,0xe002,0xe3b0,0xffff,0xffff,0xf75c,0xe867,0xe800,0xe370,0xffff,0xffff,0xf73d,0xd002,0xec52,0xffff,0xffff,0xf5f8,0xd802,0xe800,0xec93,0xffff,0xffff,0xee39,0xd803,0xe804,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xf847,0x5062,0x0000,0xe0c6,0xe8a7,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xf086,0xd803,0xed97,0xffff,0xffff,0xed77,0xe803,0xe803,0xd1e9,0xffff,0xffff,0xffff,0xc9eb,0xed97,0xffff,0xffff,0xe411,0xe000,0xe801,0xe28d,0xffff,0xffff,0xffdf,0xd8c8,0xe003,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xf805,0xd866,0x1841,0x0000,
0xf086,0xe0c6,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xf005,0xd0c6,0xf75d,0xffff,0xffff,0xe371,0xd801,0xe845,0xd845,0xf69b,0xffff,0xffff,0xdd97,0xeedc,0xffff,0xffff,0xda0b,0xe802,0xe003,0xe087,0xffbf,0xffff,0xffff,0xdaae,0xd801,0xf005,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xf825,0xa064,0x0020,0x0020,0xe8a7,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe8c6,0xe003,0xe24b,0xffff,0xffff,0xffff,0xd9ca,0xe003,0xe0a6,0xe802,0xecd4,0xffff,0xffff,0xffff,0xffff,0xffff,0xf77d,0xe045,0xe804,0xe804,0xd002,0xedfa,0xffff,0xffff,0xec94,0xd800,0xe806,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe806,0xf846,0x5042,0x0020,0x0821,
0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe0c6,0xd802,0xe432,0xffff,0xffff,0xf69b,0xd845,0xf045,0xe8a6,0xe002,0xeaee,0xffff,0xffff,0xffff,0xffff,0xffff,0xed76,0xe002,0xe805,0xf004,0xd800,0xdc12,0xffff,0xffff,0xf69a,0xd804,0xe804,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xf805,0xd045,0x0061,0x0021,0x0820,0xf886,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xf065,0xd804,0xee19,0xffff,0xffff,0xecf5,0xd802,0xe8a6,0xe0c6,0xe024,0xe128,0xf7de,0xffff,0xffff,0xffff,0xffff,0xe390,0xe000,0xe805,0xf005,0xe801,0xe20b,0xffff,0xffff,0xffff,0xe129,0xe802,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xf826,0x6062,0x0000,0x0821,0x0040,
0xf8c7,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe8a7,0xf003,0xd127,0xf79f,0xffff,0xffff,0xe30f,0xe002,0xe0c6,0xe8a6,0xe865,0xd804,0xee39,0xffff,0xffff,0xffff,0xffff,0xd96a,0xe002,0xe825,0xe805,0xe804,0xd845,0xf75d,0xffff,0xffff,0xe32f,0xd800,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xf806,0xc845,0x0041,0x0020,0x0820,0x0821,0xd0c7,0xf8c6,0xe886,0xe886,0xe0a7,0xe8a6,0xe002,0xdacd,0xffff,0xffff,0xf7df,0xd949,0xe803,0xe887,0xe0a6,0xe8a5,0xd802,0xec33,0xffff,0xffff,0xffff,0xf6fc,0xd804,0xf004,0xe805,0xe805,0xe805,0xd801,0xed56,0xffff,0xffff,0xed36,0xd801,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe806,0xf005,0xf846,0x4842,0x0000,0x0041,0x0040,0x0821,
0x58a4,0xf8a8,0xf0a6,0xe0a5,0xf087,0xe8a6,0xd803,0xf495,0xffff,0xffff,0xee5a,0xd804,0xe864,0xe887,0xe0c6,0xe8a6,0xe003,0xd2ad,0xffff,0xf7ff,0xffff,0xecf5,0xd801,0xe805,0xe805,0xe805,0xe805,0xe000,0xe36f,0xffff,0xffff,0xf73d,0xe066,0xe803,0xe806,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xf005,0xe805,0xf827,0x9884,0x0020,0x0020,0x0041,0x0021,0x0821,0x00c2,0x88c5,0xf8c8,0xf865,0xe8a6,0xe086,0xd004,0xf67a,0xffff,0xffff,0xe4b4,0xd801,0xf085,0xe886,0xe887,0xe8a6,0xe823,0xd8c7,0xf7ff,0xffff,0xffff,0xe2ef,0xe000,0xe805,0xe805,0xe805,0xe805,0xe002,0xd96a,0xffff,0xffff,0xffff,0xe149,0xe002,0xe806,0xe805,0xe805,0xe805,0xe805,0xe805,0xe005,0xe025,0xf826,0xd866,0x1021,0x0020,0x0841,0x0841,0x0821,0x0821,
0x08c3,0x00c1,0xb0e6,0xf8a8,0xe0a6,0xe8a6,0xe803,0xdb2f,0xf7df,0xef3c,0xe169,0xe823,0xe0a6,0xe8a5,0xf086,0xe0c6,0xe885,0xe804,0xd411,0xffff,0xee5a,0xd865,0xf003,0xe025,0xe805,0xe805,0xe805,0xe804,0xe004,0xe535,0xffff,0xe557,0xd843,0xe804,0xe806,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xf806,0xe886,0x2862,0x0020,0x0061,0x0841,0x0841,0x0841,0x0841,0x20a3,0x08a2,0x10c2,0xc0e6,0xf887,0xe885,0xe8a5,0xd804,0xd969,0xd907,0xe804,0xe8a7,0xe0a6,0xe0a6,0xe886,0xe0a6,0xe8a6,0xe866,0xd003,0xd928,0xd825,0xe803,0xe806,0xe006,0xe805,0xe805,0xe805,0xe805,0xe804,0xd004,0xd949,0xe004,0xe003,0xe806,0xe805,0xe805,0xe005,0xe805,0xe805,0xe005,0xf806,0xf847,0x4061,0x0000,0x0821,0x0840,0x0821,0x0841,0x0841,0x0841,
0x18c3,0x18e4,0x00a2,0x2881,0xd0c6,0xf8a7,0xe0a6,0xe0a6,0xe804,0xe804,0xe0a6,0xe8a6,0xe8a6,0xe8a6,0xe0a6,0xe886,0xe8a6,0xe066,0xe804,0xe803,0xe804,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe804,0xe802,0xe804,0xe806,0xe805,0xe805,0xe805,0xe805,0xe025,0xe805,0xf826,0xf847,0x5882,0x0060,0x0041,0x0841,0x0821,0x0841,0x0841,0x0841,0x0841,0x18c3,0x18e3,0x18e2,0x00c2,0x2082,0xb8e6,0xf8c8,0xf866,0xe0a6,0xe0a6,0xe886,0xe0a6,0xe8a6,0xe8a6,0xe8a6,0xe8a6,0xe886,0xe025,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe806,0xe005,0xf826,0xf067,0x4862,0x0040,0x0841,0x0841,0x0841,0x1021,0x0841,0x0841,0x0841,0x0841,
0x18c3,0x18c3,0x18c2,0x18c4,0x00c2,0x1081,0x98c5,0xf8a7,0xf8a6,0xd8c5,0xe8a6,0xe8a6,0xe0a6,0xe8a6,0xe8a6,0xe8a6,0xe866,0xe005,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xf005,0xf826,0xd066,0x2862,0x0020,0x0061,0x1021,0x1021,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x08c3,0x00a2,0x58c4,0xe0e7,0xf8a7,0xf086,0xe886,0xe886,0xe0a6,0xe0a6,0xe8a6,0xe825,0xe805,0xe805,0xe805,0xe805,0xe805,0xe005,0xe805,0xe805,0xe805,0xe806,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe005,0xe805,0xf806,0xf846,0x9084,0x1061,0x0020,0x0841,0x0841,0x0061,0x0821,0x1021,0x0041,0x0841,0x0841,0x0841,0x0841,
0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x10e4,0x00a2,0x28a2,0xa085,0xf0a7,0xf8c7,0xf886,0xe886,0xe8a6,0xe886,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe825,0xe025,0xe025,0xf005,0xe805,0xf006,0xf826,0xf846,0xc085,0x4062,0x0000,0x0041,0x0861,0x0861,0x1041,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18e2,0x18c3,0x0000,0x0000,0x2000,0x7800,0xe045,0xf8a7,0xf887,0xf046,0xe804,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xe805,0xf006,0xe006,0xf806,0xf826,0xf846,0xc845,0x6043,0x0041,0x0020,0x0821,0x0841,0x0861,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,
0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x10c3,0x0000,0x5a6a,0xc658,0xbe99,0x7c31,0x3082,0x7043,0xc0e6,0xe866,0xf826,0xf826,0xf825,0xf805,0xf805,0xf805,0xf005,0xf026,0xf006,0xf806,0xf826,0xf826,0xf825,0xf846,0xd846,0x9064,0x5063,0x0061,0x0041,0x0021,0x0861,0x0861,0x0861,0x0861,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x0000,0x634c,0xffff,0xd65a,0xa555,0xffff,0xb659,0x0040,0x0861,0x3001,0x6863,0x8803,0xb004,0xc845,0xd866,0xd804,0xd805,0xe045,0xe044,0xd845,0xb824,0xa023,0x8084,0x4862,0x1000,0x0000,0x0060,0x0000,0x0041,0x0020,0x0000,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,
0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x1062,0x1082,0xffff,0xce79,0x0000,0x0000,0x5aca,0xffff,0x6b8e,0x0000,0x0000,0x0000,0x0020,0x18c3,0x1821,0x0800,0x3883,0x4063,0x1000,0x2821,0x2062,0x0000,0x0000,0x0041,0x0041,0x0000,0x0000,0x0861,0x0000,0x0000,0x0020,0x1062,0x0000,0x0821,0x0861,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x0841,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x0000,0x39e8,0xffff,0x6b4d,0x0000,0x1062,0x18a3,0x8c71,0x4a29,0x0821,0xb5b6,0x9492,0xf7be,0x638e,0x0000,0x7c51,0xe7de,0xdfbe,0x6bef,0x0000,0x0000,0xb5f7,0x94f3,0x0000,0x0862,0xce59,0x738e,0x0000,0xad75,0x9cf4,0xce59,0xffdf,0x7bcf,0x0000,0x0841,0x0841,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,
0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x0000,0x4a29,0xffff,0x6b4d,0x0000,0x0020,0x0000,0x0000,0x0000,0x1082,0xffff,0xffff,0x9cb3,0x18c3,0x6b4d,0xffff,0x634d,0x738e,0xffff,0x630c,0x0000,0xffff,0xe71c,0x0000,0x1062,0xffff,0xa514,0x0000,0xffff,0xffff,0x630c,0xa514,0xffff,0x4228,0x0000,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x0000,0x4208,0xffff,0x6b6d,0x0000,0x632c,0x8c51,0x6b4d,0x18e3,0x0841,0xffff,0xad35,0x0000,0x0000,0xffff,0xd679,0x0000,0x0000,0xe6fb,0xe73c,0x0000,0xef5d,0xce59,0x0000,0x1062,0xffff,0x9492,0x0000,0xffff,0xb596,0x0000,0x0000,0xffff,0xad55,0x0000,0x0841,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,
0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x0000,0x4228,0xffff,0x6b4d,0x0000,0x9cb3,0xef5d,0xffff,0x6b6d,0x0000,0xffff,0x9cd3,0x0000,0x0861,0xffff,0x9cf4,0x0000,0x0000,0xad75,0xffff,0x0000,0xef3d,0xce39,0x0000,0x1062,0xffff,0x9492,0x0000,0xffff,0xad75,0x0000,0x0000,0xf79e,0xce59,0x0000,0x0841,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x0000,0x4a29,0xffff,0x632c,0x0000,0x0000,0x2104,0xffff,0x738e,0x0000,0xffff,0xa514,0x0000,0x1062,0xffff,0xa4f4,0x0000,0x0000,0xad55,0xffff,0x0000,0xef5d,0xc638,0x0000,0x1062,0xffff,0x9492,0x0000,0xffff,0xb596,0x0000,0x0000,0xef5d,0xce79,0x0000,0x0841,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,
0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x0821,0x2945,0xffff,0x9472,0x0000,0x0000,0x1082,0xffff,0x7bcf,0x0000,0xffff,0xa514,0x0000,0x0000,0xffff,0xbdd7,0x0000,0x0000,0xce79,0xf7be,0x0000,0xef7d,0xce79,0x0000,0x0000,0xffff,0x94b2,0x0000,0xffff,0xa534,0x0000,0x0000,0xffdf,0xc618,0x0000,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x0000,0xce39,0xffff,0x4a29,0x10a2,0x8c51,0xffff,0x528a,0x0000,0xffff,0xb576,0x0000,0x0000,0xa534,0xffff,0x2925,0x3186,0xffff,0x9492,0x0000,0xbdf7,0xffff,0x2124,0x6b4d,0xffff,0x8c71,0x0000,0xef7d,0xef5d,0x2945,0x5acb,0xffff,0x738e,0x0000,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,
0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18e3,0x0841,0x1082,0xbdd7,0xffff,0xf79e,0xffff,0x8410,0x0000,0x0841,0xf79e,0x9cb3,0x0000,0x0821,0x0841,0xbdf7,0xffff,0xffff,0xb596,0x0020,0x0000,0x2945,0xef7d,0xffff,0xb576,0xd6ba,0x8430,0x0000,0xe6fc,0xef5d,0xce79,0xffff,0xb576,0x0000,0x0821,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x20e4,0x0841,0x0000,0x4208,0x5acb,0x2104,0x0000,0x0841,0x1082,0x20e4,0x18c3,0x0861,0x1082,0x0000,0x0000,0x4a29,0x4228,0x0000,0x0000,0x1062,0x0000,0x18c3,0x4a29,0x0821,0x1062,0x1082,0x0821,0xffff,0xa514,0x18e3,0x4208,0x0000,0x0000,0x1082,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,
0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18e3,0x18a3,0x0821,0x0000,0x0000,0x1062,0x1082,0x1062,0x0000,0x0020,0x1082,0x1062,0x1082,0x0841,0x0000,0x0000,0x0841,0x1082,0x1082,0x1082,0x0000,0x0000,0x0841,0x0000,0x0000,0x0841,0xffff,0xc618,0x0000,0x0000,0x0841,0x1082,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18e3,0x1082,0x0861,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1082,0x0000,0x0000,0x0841,0xf79e,0xad55,0x0000,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,
0x18c3,0x18c3,0x18e3,0x18c3,0x18c3,0x18c3,0x18c3,0x18e3,0x18e3,0x18c3,0x1062,0x1062,0x1082,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1082,0x1062,0x1062,0x1062,0x0020,0x6b2d,0x9cd3,0x1062,0x18c3,0x18e3,0x1062,0x1062,0x1082,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x1062,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18e3,0x10a2,0x1062,0x1082,0x1082,0x1082,0x1082,0x1062,0x1082,0x1082,0x1082,0x1082,0x1082,0x1082,0x1082,0x1082,0x1082,0x1062,0x1082,0x1082,0x1062,0x0000,0xb576,0xffff,0x1062,0x0000,0x0000,0x1082,0x1082,0x1082,0x1082,0x1082,0x1082,0x1082,0x1062,0x1082,0x1082,0x1082,0x1082,0x1082,0x1082,0x1082,
0x18c3,0x18c3,0x0020,0x0000,0x1062,0x18e3,0x10a2,0x0020,0x1082,0x10a2,0x0020,0x0000,0x0861,0x1082,0x0821,0x0000,0x0000,0x1062,0x1082,0x0841,0x0000,0x0821,0x0000,0x1062,0x1082,0x0000,0x0000,0x0000,0x1082,0x1082,0x0020,0x0000,0x1082,0x1082,0x0841,0x0000,0x0000,0x0841,0x1082,0x1082,0x1082,0x0000,0x0000,0x0000,0x1082,0x1082,0x1082,0x1082,0x1082,0x1082,0x18c3,0x0000,0x39c7,0x5aab,0x18a3,0x0020,0x2965,0x39c7,0x1082,0x1062,0x0841,0x3186,0x18e3,0x0000,0x0821,0x526a,0x39a7,0x0000,0x1082,0x18e3,0x18e3,0x0841,0x4208,0x18c3,0x0000,0x20e4,0x528a,0x2104,0x0000,0x1082,0x10a2,0x10a2,0x10a2,0x0000,0x0000,0x526a,0x4a49,0x0000,0x0821,0x1082,0x0000,0x2945,0x528a,0x1082,0x0000,0x1082,0x1082,0x1082,0x1082,0x1082,
0x0000,0x7baf,0xffff,0xffff,0xdefb,0x18c3,0x2124,0xffff,0x9492,0x0000,0xb596,0xffff,0x18a3,0x1082,0xd69a,0xffff,0xffff,0x7bef,0x0000,0x6b4d,0xef5d,0xdebb,0xffff,0x0020,0x4a49,0xffff,0xffbf,0xffff,0x52aa,0x0000,0xa514,0xffbf,0x0821,0x1062,0xbdf7,0xffdf,0xffff,0xb596,0x0861,0x0000,0x632c,0xffff,0xffff,0xef3d,0x2945,0x0020,0x1082,0x1082,0x1082,0x1082,0x39e7,0xffff,0x8c31,0x18a3,0xffff,0xc638,0x0000,0xc5f8,0xffff,0x18e3,0xffff,0x9cf3,0x0000,0xc638,0xffff,0x18c3,0x7baf,0xffff,0x10a2,0x528a,0xffff,0xb596,0x39c7,0x1082,0xffff,0xc5f8,0x18a3,0xce7a,0xffff,0x0020,0xa534,0xffff,0x0000,0x9472,0xffff,0x0020,0x41e8,0xffff,0x632c,0x0020,0xffff,0x9cd3,0x10a2,0xf7be,0xdedb,0x0000,0x1062,0x1082,0x1082,0x1082,
0x9cb3,0xffff,0x18c3,0x0000,0xb596,0xffff,0x0020,0x18a3,0xef7d,0xe6fc,0xef5d,0x0000,0x0841,0xffff,0x9cd3,0x0000,0x18c3,0xffff,0x52aa,0x4208,0xffff,0x1903,0x0000,0x62ec,0xffff,0x31c7,0x0000,0x39c7,0xce59,0x0841,0x9c93,0xffff,0x0000,0x9471,0xffff,0x2104,0x0000,0x41e8,0x2925,0x6b4d,0xffff,0x2104,0x0000,0x9cb3,0xffff,0x1082,0x0000,0x1082,0x1082,0x1082,0x9492,0xffff,0xe6fc,0xdefb,0xffff,0xf77e,0x18c3,0x0000,0x7bef,0xffff,0x6b4d,0x0000,0x2925,0xf7be,0xef7d,0xdebb,0xe73c,0xffff,0x4a69,0x3a28,0xffff,0x3186,0x0000,0x634d,0xffff,0x31a6,0x0000,0x0020,0x0000,0x0000,0xb556,0xffff,0x0841,0x0841,0xb5b6,0xffff,0xad35,0x0000,0x0000,0x8c71,0xffff,0xe6fc,0xdedb,0xffdf,0xffdf,0x18e3,0x0000,0x1082,0x1082,0x1082,
0xa514,0xffff,0x62ec,0x5aeb,0x52aa,0x39e7,0x10a2,0x0000,0xa514,0xffff,0x9472,0x0000,0x2104,0xffff,0xad55,0x4a8a,0x52cb,0x4208,0x0861,0x6b4d,0xffff,0x5187,0x0000,0x736e,0xffff,0x49a8,0x0000,0x0000,0x0000,0x0000,0x9d95,0xffff,0x18a3,0x0000,0x0000,0x5aeb,0xffdf,0xef7d,0x1082,0x73ae,0xffff,0x630c,0x5aab,0x528a,0x39a7,0x10a2,0x1082,0x1082,0x1082,0x1082,0x9472,0xffff,0x0020,0x0000,0x0000,0x0000,0x0000,0x4228,0xffff,0x9cd3,0xffff,0x2925,0x0000,0xffff,0xa4f3,0x0000,0x1000,0x2800,0x4000,0xabb0,0xffff,0x89a8,0x5000,0x9a6c,0xffff,0x822a,0x3000,0x69e8,0xceba,0x2822,0xa4b2,0xffff,0x0021,0x8451,0x7bcf,0x0000,0x0000,0xffff,0x7baf,0x39e7,0xffff,0x1082,0x0000,0x0000,0x0000,0x10a2,0x18a3,0x1082,0x1082,0x1082,
0x2124,0xffff,0xdebb,0x528a,0xad55,0x8430,0x0000,0xffff,0xf79e,0x0000,0xffff,0xe75d,0x0800,0xacd3,0xffff,0xa34e,0xb2ed,0xe5d7,0x7842,0xb30e,0xffff,0x91a8,0x7000,0x7022,0xf79e,0xff3d,0x9aca,0xffbf,0xffff,0x5801,0xd577,0xffff,0x1000,0xad55,0xffff,0x4aaa,0x632c,0xffff,0x632c,0x0000,0xffdf,0xef3d,0x52aa,0x9cf3,0x9cb3,0x0000,0x1082,0x1082,0x1082,0x1082,0x0000,0x4a49,0xe71c,0xf79e,0xe71c,0x4a6a,0x2904,0xe6fc,0x4b0c,0x0000,0x836e,0xef1c,0x80e6,0x6801,0xc4d4,0xffbf,0xf79e,0xd576,0x7002,0x9a4a,0xe65a,0x8946,0x7021,0x7000,0x8927,0xe69b,0xf7be,0xe63a,0x7906,0x6800,0xc3f2,0xde39,0x7823,0x5001,0xbcb3,0xf77d,0xdf7d,0x8431,0x0821,0x0000,0x39a6,0xdedb,0xf79e,0xe73c,0x6b2d,0x0020,0x1082,0x10a2,0x10a2,0x10a2,
0x20e4,0x0000,0x0841,0x2124,0x0841,0x0000,0x18e3,0x0020,0x0801,0x6063,0x6801,0x7002,0x88a4,0x7022,0x6800,0x7885,0x8064,0x6800,0x7063,0x7043,0x7802,0x7823,0x8044,0x8064,0x6801,0x7002,0x78a5,0x6802,0x6801,0x7863,0x7802,0x7002,0x8064,0x8002,0x7000,0x7085,0x3863,0x0000,0x0082,0x2083,0x0000,0x0000,0x18e3,0x0000,0x0000,0x18a3,0x10a2,0x10a2,0x10a2,0x10a2,0x18e3,0x18e3,0x1082,0x1062,0x18a3,0x08a2,0x0081,0x3841,0x8043,0x9045,0x8024,0x8003,0x7843,0x7863,0x7843,0x7802,0x7802,0x7863,0x7863,0x7843,0x7042,0x8044,0x8044,0x7864,0x8044,0x8003,0x7802,0x7823,0x8044,0x8024,0x7063,0x7803,0x8824,0x8044,0x8023,0x7803,0x8003,0x5843,0x10a3,0x00a2,0x18a2,0x1061,0x0821,0x1061,0x18a3,0x10a2,0x10a2,0x10a2,0x10a2,0x10a2,
0x18c3,0x18e3,0x18c3,0x20e4,0x08c2,0x1062,0x5864,0x8864,0x8863,0x8044,0x8044,0x8064,0x8044,0x8044,0x8064,0x8044,0x8064,0x8044,0x8044,0x8044,0x7864,0x7864,0x7864,0x7864,0x8044,0x8043,0x7864,0x8063,0x8044,0x8044,0x7864,0x8044,0x8064,0x7864,0x8044,0x8064,0x8063,0x9844,0x7844,0x2082,0x0082,0x10a2,0x18a3,0x10a3,0x10a2,0x10a2,0x10a3,0x10a2,0x10a2,0x10a2,0x18e3,0x20c3,0x20c4,0x10e3,0x18a2,0x6864,0x9044,0x8044,0x7844,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8864,0x8065,0x3863,0x00a2,0x08c3,0x1883,0x10a2,0x10a2,0x18a2,0x10a2,0x10a2,0x10a2,
0x18c3,0x18c3,0x10c3,0x20a3,0x7064,0x9044,0x8044,0x7864,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x7864,0x7864,0x8823,0x9044,0x8865,0x3863,0x00c2,0x10a3,0x1883,0x10a3,0x10a2,0x10a2,0x10a2,0x10a2,0x20c3,0x08e3,0x18e3,0x7085,0x9024,0x8044,0x7864,0x8044,0x8064,0x7864,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x7864,0x8043,0x8043,0x7863,0x8844,0x9045,0x3863,0x00c2,0x10c3,0x1882,0x10a2,0x10a2,0x10a2,0x10a2,
0x10e3,0x10e3,0x60c5,0x9045,0x8044,0x8044,0x8044,0x8044,0x8044,0x8064,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8044,0x8064,0x8043,0x8044,0x7864,0x8044,0x8844,0x8845,0x3082,0x08a2,0x18a3,0x18a3,0x18a3,0x18a3,0x18a3,0x18c3,0x68c4,0x9885,0x8844,0x8864,0x9044,0x9044,0x8844,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x9044,0x8844,0x8844,0x8844,0x9044,0x8844,0x8864,0x9864,0x9045,0x2883,0x08c3,0x18a3,0x18a3,0x18a3,0x18a3,
0x20e4,0x68a5,0x58a3,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5883,0x5083,0x5863,0x5864,0x48a3,0x6084,0x38a3,0x10a2,0x18a3,0x18a3,0x18a3,0x18a3,0x20c3,0x0903,0x08c3,0x08a3,0x08a3,0x08a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x10a3,0x08a3,0x10a3,0x1083,0x08c2,0x18a3,0x18a3,0x10c3,0x18a3,0x18a3,0x18a3,
0x28c4,0x18e3,0x10a3,0x18a3,0x18a3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10c3,0x10a3,0x10c3,0x10e3,0x18a3,0x18a3,0x10c3,0x18a3,0x18a3,0x18a3,0x18a3,0x18a3,0x18e4,0x20a3,0x18a2,0x18c3,0x18a3,0x18a3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18a2,0x18a2,0x10c2,0x18c3,0x18c2,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,
0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18a3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18a3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,
0x18c3,0x18a3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18a3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,0x18c3,

};


